( function( wp ) {
    const el = wp.element.createElement;
    const registerBlockType = wp.blocks.registerBlockType;
    const MediaUpload = wp.blockEditor.MediaUpload;
    const MediaUploadCheck = wp.blockEditor.MediaUploadCheck;
    const InspectorControls = wp.blockEditor.InspectorControls;
    const Button = wp.components.Button;
    const SelectControl = wp.components.SelectControl;
    const TextControl = wp.components.TextControl;
    const ToggleControl = wp.components.ToggleControl;
    const PanelBody = wp.components.PanelBody;
    const NumberControl = wp.components.__experimentalNumberControl;
    const __ = wp.i18n.__;

    registerBlockType( 'stereopix/media-viewer', {
        title: __( 'Stereopix Media Viewer', 'stereopix-media-viewer' ),
        icon: 'format-image',
        category: 'media',
        attributes: {
            mediaItems: {
                type: 'array',
                default: [],
                items: {
                    type: 'object',
                    properties: {
                        id: { type: 'number' },
                        url: { type: 'string' },
                        title: { type: 'string' },
                        caption: { type: 'string' },
                    },
                },
            },
            format: { type: 'string', default: 'parallel' },
            width: { type: 'string', default: '100%' },
            height: { type: 'string', default: '600px' },
            filterStereoscopic: { type: 'boolean', default: false },
            initialMediaIndex: { type: 'number', default: 0 },
            showTitle: { type: 'boolean', default: false },
            showCaption: { type: 'boolean', default: false },
        },
        edit: function( props ) {
            const { attributes, setAttributes } = props;
            const { mediaItems, format, width, height, filterStereoscopic, initialMediaIndex, showTitle, showCaption } = attributes;

            const onSelectImages = ( media ) => {
                setAttributes( {
                    mediaItems: media.map( item => ( {
                        id: item.id,
                        url: item.url,
                        title: item.title && item.title.rendered ? item.title.rendered : '',
                        caption: item.caption && item.caption.rendered ? item.caption.rendered : '',
                    } ) ),
                    initialMediaIndex: Math.min( initialMediaIndex, media.length - 1 ),
                } );
            };

            return el(
                'div',
                { className: 'stereopix-block' },
                el(
                    InspectorControls,
                    null,
                    el(
                        PanelBody,
                        { title: __( 'Stereopix Settings', 'stereopix-media-viewer' ) },
                        el(
                            ToggleControl,
                            {
                                label: __( 'Filter Stereoscopic Images', 'stereopix-media-viewer' ),
                                checked: filterStereoscopic,
                                onChange: ( value ) => setAttributes( { filterStereoscopic: value } ),
                                help: __( 'Only show images marked as stereoscopic in the Media Library.', 'stereopix-media-viewer' ),
                            }
                        ),
                        el(
                            NumberControl,
                            {
                                label: __( 'Initial Image Index', 'stereopix-media-viewer' ),
                                value: initialMediaIndex,
                                onChange: ( value ) => {
                                    const index = parseInt( value, 10 );
                                    if ( ! isNaN( index ) && index >= 0 && index < mediaItems.length ) {
                                        setAttributes( { initialMediaIndex: index } );
                                    }
                                },
                                min: 0,
                                max: mediaItems.length - 1 || 0,
                                help: __( 'Select which image to display first (0 is the first image).', 'stereopix-media-viewer' ),
                            }
                        ),
                        el(
                            ToggleControl,
                            {
                                label: __( 'Show Titles', 'stereopix-media-viewer' ),
                                checked: showTitle,
                                onChange: ( value ) => setAttributes( { showTitle: value } ),
                                help: __( 'Display image titles below the viewer if available.', 'stereopix-media-viewer' ),
                            }
                        ),
                        el(
                            ToggleControl,
                            {
                                label: __( 'Show Captions', 'stereopix-media-viewer' ),
                                checked: showCaption,
                                onChange: ( value ) => setAttributes( { showCaption: value } ),
                                help: __( 'Display image captions below the viewer if available.', 'stereopix-media-viewer' ),
                            }
                        )
                    )
                ),
                el(
                    MediaUploadCheck,
                    null,
                    el(
                        MediaUpload,
                        {
                            onSelect: onSelectImages,
                            allowedTypes: [ 'image' ],
                            value: mediaItems.map( item => item.id ),
                            gallery: true,
                            multiple: true,
                            render: ( { open } ) => el(
                                Button,
                                {
                                    onClick: open,
                                    className: 'button button-large',
                                },
                                mediaItems.length ? __( 'Change Images', 'stereopix-media-viewer' ) : __( 'Select Images', 'stereopix-media-viewer' )
                            ),
                        }
                    )
                ),
                mediaItems.length > 0 && el(
                    'div',
                    { style: { display: 'flex', flexWrap: 'wrap', gap: '10px', maxWidth: '100%' } },
                    mediaItems.map( ( item, index ) => el(
                        'div',
                        { key: item.id, style: { maxWidth: '100px', textAlign: 'center' } },
                        el(
                            'img',
                            {
                                src: item.url,
                                alt: __( `Selected stereoscopic image ${index + 1}`, 'stereopix-media-viewer' ),
                                style: { maxWidth: '100px', height: 'auto' },
                            }
                        ),
                        showTitle && item.title && el(
                            'p',
                            { className: 'stereopix-title-preview', style: { fontSize: '12px', margin: '5px 0 0 0' } },
                            item.title
                        ),
                        showCaption && item.caption && el(
                            'p',
                            { className: 'stereopix-caption-preview', style: { fontSize: '12px', margin: '5px 0 0 0' } },
                            item.caption
                        )
                    ) )
                ),
                el(
                    SelectControl,
                    {
                        label: __( 'Format', 'stereopix-media-viewer' ),
                        value: format,
                        options: [
                            { label: __( 'Single Left', 'stereopix-media-viewer' ), value: 'single_left' },
                            { label: __( 'Single Right', 'stereopix-media-viewer' ), value: 'single_right' },
                            { label: __( 'Parallel', 'stereopix-media-viewer' ), value: 'parallel' },
                            { label: __( 'Cross', 'stereopix-media-viewer' ), value: 'cross' },
                            { label: __( 'Mirrored Left', 'stereopix-media-viewer' ), value: 'mirrored_left' },
                            { label: __( 'Mirrored Right', 'stereopix-media-viewer' ), value: 'mirrored_right' },
                            { label: __( 'Mirrored Both', 'stereopix-media-viewer' ), value: 'mirrored_both' },
                            { label: __( 'Top-Bottom', 'stereopix-media-viewer' ), value: 'top_bottom' },
                            { label: __( 'Bottom-Top', 'stereopix-media-viewer' ), value: 'bottom_top' },
                            { label: __( 'Top-Bottom Anamorphic', 'stereopix-media-viewer' ), value: 'top_bottom_anamorphic' },
                            { label: __( 'Bottom-Top Anamorphic', 'stereopix-media-viewer' ), value: 'bottom_top_anamorphic' },
                            { label: __( 'Interleaved Lines 1', 'stereopix-media-viewer' ), value: 'interleaved_lines_1' },
                            { label: __( 'Interleaved Lines 2', 'stereopix-media-viewer' ), value: 'interleaved_lines_2' },
                            { label: __( 'Interleaved Columns 1', 'stereopix-media-viewer' ), value: 'interleaved_columns_1' },
                            { label: __( 'Interleaved Columns 2', 'stereopix-media-viewer' ), value: 'interleaved_columns_2' },
                            { label: __( 'Checkerboard 1', 'stereopix-media-viewer' ), value: 'checkerboard_1' },
                            { label: __( 'Checkerboard 2', 'stereopix-media-viewer' ), value: 'checkerboard_2' },
                            { label: __( 'Anaglyph Red/Cyan Gray', 'stereopix-media-viewer' ), value: 'anaglyph_red_cyan_gray' },
                            { label: __( 'Anaglyph Red/Cyan Dubois', 'stereopix-media-viewer' ), value: 'anaglyph_red_cyan_dubois' },
                            { label: __( 'Anaglyph Green/Magenta Dubois', 'stereopix-media-viewer' ), value: 'anaglyph_green_magenta_dubois' },
                            { label: __( 'Anaglyph Yellow/Blue Dubois', 'stereopix-media-viewer' ), value: 'anaglyph_yellow_blue_dubois' },
                            { label: __( 'sView', 'stereopix-media-viewer' ), value: 'sview' },
                            { label: __( 'WebXR', 'stereopix-media-viewer' ), value: 'webxr' },
                        ],
                        onChange: ( value ) => setAttributes( { format: value } ),
                    }
                ),
                el(
                    TextControl,
                    {
                        label: __( 'Width', 'stereopix-media-viewer' ),
                        value: width,
                        onChange: ( value ) => setAttributes( { width: value } ),
                    }
                ),
                el(
                    TextControl,
                    {
                        label: __( 'Height', 'stereopix-media-viewer' ),
                        value: height,
                        onChange: ( value ) => setAttributes( { height: value } ),
                    }
                )
            );
        },
        save: function() {
            return null; // Dynamic block, rendered server-side
        },
    } );
} )( window.wp );